package fortyonepost.com.hexadecimalcolorinput; //41 Post - Created by DimasTheDriver on Feb/23/2013 . Part of the 'Android: hexadecimal color input using an EditText' post. Available at: http://www.41post.com/?p=5108

import android.os.Bundle;
import android.app.Activity;
import android.graphics.PorterDuff;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.Toast;

public class MainActivity extends Activity 
{
	//The ImageView that displays the hexadecimal color
	private ImageView iv_colorpreview;
	//The EditText field, that receives a hexadecimal color as input
	private EditText et_hexColorInput;
	//A button to confirm any color changes
	private Button bt_ok;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) 
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		//Inflate the three previous Views with the information found at the 'activity_main.xml' file 
		this.iv_colorpreview = (ImageView) this.findViewById(R.id.iv_colorpreview);
		this.et_hexColorInput = (EditText) this.findViewById(R.id.et_hexcolor);
		this.bt_ok = (Button) this.findViewById(R.id.bt_ok);
		
		//This prevents the EditText View from automatically receiving focus on Activity startup 
		this.getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_ALWAYS_HIDDEN);
		
		//Assign a TextWatcher to the EditText
		this.et_hexColorInput.addTextChangedListener(new TextWatcher() 
		{
			@Override
			public void onTextChanged(CharSequence s, int start, int before, int count){}
			
			@Override
			public void beforeTextChanged(CharSequence s, int start, int count,int after){}
			
			//Right after the text is changed
			@Override
			public void afterTextChanged(Editable s) 
			{
				//Store the text on a String
				String text = s.toString();
				
				//Get the length of the String
				int length = s.length();
				
				/*If the String length is bigger than zero and it's not
				composed only by the following characters: A to F and/or 0 to 9 */
				if(!text.matches("[a-fA-F0-9]+") && length > 0)
				{
					//Delete the last character
					s.delete(length - 1, length);
				}
			}
		});
		
		//Set what the OK Button should do, when pressed
		this.bt_ok.setOnClickListener(new OnClickListener() 
		{
			@Override
			public void onClick(View v) 
			{
				//Create and initialize the int 'color' with the white color. 
				int color = 0xFFFFFFFF;
				
				try 
				{
					//Get the text at the EditText field and save it in a String
					String colorValue = et_hexColorInput.getText().toString();
					
					/*Convert the String into a Color ARGB hexadecimal integer.*/
					color = Integer.parseInt(colorValue.substring(2), 16) + 
							(Integer.parseInt(colorValue.substring(0,2), 16) << 24);
				}
				catch (Exception e) //Something went wrong while parsing the String into an Integer
				{
					//Reset the EditText field to white
					MainActivity.this.et_hexColorInput.setText("FFFFFFFF");
					//Display a toast message
					Toast.makeText(MainActivity.this, "Invalid color!", Toast.LENGTH_SHORT).show();
				}
				
				/*Get the Drawable displayed by the Image View (in this case, the 1x1 PNG opaque white image).
				  Clear any ColorFilters previously applied to it*/
				MainActivity.this.iv_colorpreview.getDrawable().clearColorFilter();
				//Multiply the white image with the hexadecimal color passed at the EditText field
				MainActivity.this.iv_colorpreview.getDrawable().setColorFilter(color, PorterDuff.Mode.MULTIPLY);
				//Invalidate the ImageView, forcing it to be re-rendered.
				MainActivity.this.iv_colorpreview.invalidate();
			}
		});		
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) 
	{
		// Inflate the menu. This adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) 
	{
        switch (item.getItemId()) 
        {
        	//If the only button at this options menu is pressed
        	case R.id.menu_settings:
        	{
        		//Remove any kind of color filter
        		this.iv_colorpreview.getDrawable().clearColorFilter();
        		//Render the ImageView again
        		this.iv_colorpreview.invalidate();
        		
        		//Reset the color to its initial value (White = 0xFFFFFFFF)
        		this.et_hexColorInput.setText("FFFFFFFF");
        		
        		return true;
        	}
        	default:
        	{
        		return super.onOptionsItemSelected(item);
        	}
        }
	}
}
